Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(252)

Unified Diff: chrome/common/safe_browsing/archive_analyzer_results.h

Issue 2900803002: Renaming zip_analyzer_results to archive_analyzer_results (Closed)
Patch Set: minor fixups Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/common/safe_browsing/archive_analyzer_results.h
diff --git a/chrome/common/safe_browsing/zip_analyzer_results.h b/chrome/common/safe_browsing/archive_analyzer_results.h
similarity index 58%
rename from chrome/common/safe_browsing/zip_analyzer_results.h
rename to chrome/common/safe_browsing/archive_analyzer_results.h
index efddbefc179963c90ee255284c5ed58ae8a94b35..0728d9331fbb9a6166c13970b61e26b9cc31dd71 100644
--- a/chrome/common/safe_browsing/zip_analyzer_results.h
+++ b/chrome/common/safe_browsing/archive_analyzer_results.h
@@ -2,11 +2,11 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
//
// This file contains the zip file analysis implementation for download
// protection, which runs in a sandboxed utility process.
-#ifndef CHROME_COMMON_SAFE_BROWSING_ZIP_ANALYZER_RESULTS_H_
-#define CHROME_COMMON_SAFE_BROWSING_ZIP_ANALYZER_RESULTS_H_
+#ifndef CHROME_COMMON_SAFE_BROWSING_ARCHIVE_ANALYZER_RESULTS_H_
+#define CHROME_COMMON_SAFE_BROWSING_ARCHIVE_ANALYZER_RESULTS_H_
#include <vector>
@@ -14,21 +14,19 @@
#include "components/safe_browsing/csd.pb.h"
namespace safe_browsing {
-namespace zip_analyzer {
-struct Results {
+struct ArchiveAnalyzerResults {
bool success;
bool has_executable;
bool has_archive;
google::protobuf::RepeatedPtrField<ClientDownloadRequest_ArchivedBinary>
archived_binary;
std::vector<base::FilePath> archived_archive_filenames;
- Results();
- Results(const Results& other);
- ~Results();
+ ArchiveAnalyzerResults();
+ ArchiveAnalyzerResults(const ArchiveAnalyzerResults& other);
+ ~ArchiveAnalyzerResults();
};
-} // namespace zip_analyzer
} // namespace safe_browsing
-#endif // CHROME_COMMON_SAFE_BROWSING_ZIP_ANALYZER_RESULTS_H_
+#endif // CHROME_COMMON_SAFE_BROWSING_ARCHIVE_ANALYZER_RESULTS_H_
« no previous file with comments | « chrome/common/safe_archive_analyzer.typemap ('k') | chrome/common/safe_browsing/archive_analyzer_results.cc » ('j') | no next file with comments »

Powered by Google App Engine
@@ -2,11 +2,11 @@
// found in the LICENSE file.
//
-// This file contains the zip file analysis implementation for download
+// This file contains the archive analyzer analysis implementation for download
// protection, which runs in a sandboxed utility process.
This is Rietveld 408576698